@@ -6,10 +6,12 @@
 #' @keywords NA
 #' 
 #' @param deseqresult Results from running \code{results(dds)} on a DESeqDataSet object.
+#' @param colname The name of the column you want to use for what DESeq puts in the row name.
 #'   
 #' @return a tidy version of the DESeq2 results.
 #' 
 #' @import dplyr
+#' @importFrom tibble as_tibble rownames_to_column
 #' 
 #' @examples
 #' \dontrun{
@@ -18,13 +20,13 @@
 #' }
 #'   
 #' @export
-deseqresult2tbl <- function(deseqresult) {
-    gene=baseMean=padj=pvalue=NULL #gets rid of the note on pkg check
+deseqresult2tbl <- function(deseqresult, colname="ensgene") {
+    gene <- baseMean <- padj <- pvalue <- stat <- NULL #gets rid of the note on pkg check
     if (class(deseqresult) != "DESeqResults") stop("Not a DESeqResults object.")
     deseqresult <- as.data.frame(deseqresult)
-    deseqresult$gene <- rownames(deseqresult)
-    rownames(deseqresult) <- NULL
-    deseqresult <- tbl_df(deseqresult)
-    deseqresult <- select(deseqresult, gene, baseMean:padj)
-    deseqresult %>% arrange(padj,pvalue, baseMean)
-}
\ No newline at end of file
+    deseqresult %>% 
+        as.data.frame() %>% 
+        rownames_to_column(var=colname) %>% 
+        as_tibble() %>% 
+        arrange(padj, pvalue, desc(stat), desc(baseMean))
+}
